@@ -77,8 +77,8 @@ get_predictions_MixMod <- function(model, fitfram, ci.lvl, linv, type, terms, ty
     if (is.null(prdat.sim) || inherits(prdat.sim, c("error", "simpleError"))) {
       insight::print_color("Error: Confidence intervals could not be computed.\n", "red")
       if (inherits(prdat.sim, c("error", "simpleError"))) {
-        cat(sprintf("* Reason: %s\n", deparse(prdat.sim[[1]], width.cutoff = 500)))
-        cat(sprintf("* Source: %s\n", deparse(prdat.sim[[2]], width.cutoff = 500)))
+        cat(sprintf("* Reason: %s\n", .safe_deparse(prdat.sim[[1]])))
+        cat(sprintf("* Source: %s\n", .safe_deparse(prdat.sim[[2]])))
       }
 
       fitfram$conf.low <- NA
