@@ -84,8 +84,8 @@ get_predictions_glmmTMB <- function(model, fitfram, ci.lvl, linv, type, terms, t
 
         insight::print_color("Error: Confidence intervals could not be computed.\n", "red")
         if (inherits(prdat.sim, c("error", "simpleError"))) {
-          cat(sprintf("* Reason: %s\n", deparse(prdat.sim[[1]], width.cutoff = 500)))
-          cat(sprintf("* Source: %s\n", deparse(prdat.sim[[2]], width.cutoff = 500)))
+          cat(sprintf("* Reason: %s\n", .safe_deparse(prdat.sim[[1]])))
+          cat(sprintf("* Source: %s\n", .safe_deparse(prdat.sim[[2]])))
         }
 
         fitfram$predicted <- prdat
