@@ -17,7 +17,7 @@ if (suppressWarnings(
   })
 
   test_that("ggeffect, lrm", {
-    expect_error(ggeffect(m1, "c12hour"))
+    expect_null(ggeffect(m1, "c12hour"))
   })
 
   test_that("ggemmeans, lrm", {
